@@ -2,11 +2,17 @@
 
 set -ex
 
-major=`echo $1 | sed "s/\..*//g"`
-minor=`echo $1 | sed "s/^[0-9]*\.\(.*\)\.[0-9]*$/\1/g"`
-rel=`echo $1 | sed "s/^.*\.//g"`
+major=`echo $1 | awk -F. '{print $1;}'`
+minor=`echo $1 | awk -F. '{print $2;}'`
+rel=`echo $1 | awk -F. '{print $3;}'`
 version=$1
 
+# check that release version matches build version!
+grep ^NEON_VERSION_MAJOR=$major\$ macros/neon.m4 || exit 1
+grep ^NEON_VERSION_MINOR=$minor\$ macros/neon.m4 || exit 1
+grep ^NEON_VERSION_RELEASE=$rel\$ macros/neon.m4 || exit 1
+grep '^NEON_VERSION_TAG=$' macros/neon.m4 || exit 1
+
 for f in config.hw; do
 in=$f.in
 out=$f
